"xpaint*Font:  *lucidabright-demibold-r-normal--17*",
"xpaint*helpFile:  /usr/share/xpaint/help/Help",
"xpaint*msgFile:  /usr/share/xpaint/messages/Messages",
"xpaint*fullpopup: False",
"xpaint*paint.undoSize:		1",
"*ok.label:			Ok",
"*stopit.label:			Cancel",
"*cancel.label:			Cancel",
"*close.label:			Close",
"*apply.label:			Apply",
"*alert.title:			Alert",
"*vertical*borderWidth:          0",
"*horizontal*borderWidth:        0",
"*vertical*shadowWidth:          1",
"*horizontal*shadowWidth:        1",
"*valueBar*shadowWidth:          1",
"*Text*shadowWidth:	        1",
"*SimpleMenu.shadowWidth:        1",
"*SimpleMenu*SmeBSB*shadowWidth: 0",
"xpaint*Toggle.SimpleMenu.translations: #override \
	<LeaveWindow>: unhighlight() MenuPopdown()\\n\
        <BtnMotion>: highlight()\\n\
        <Btn1Down>: highlight()\\n\
        <Btn1Up>: highlight() notify() MenuPopdown()\\n\
        <Btn3Down>: highlight()\\n\
        <Btn3Up>: highlight() notify()",
"xpaint*paintBox*paint*popup-menu*translations: #override \
	<Key>Escape: unhighlight() MenuPopdown()\\n\
	<LeaveWindow>: unhighlight() MenuPopdown()\\n\
        <BtnMotion>: highlight() popup-menu-pullright()\\n\
        <BtnDown>: highlight() popup-menu-pullright()\\n\
        <BtnUp>: highlight() notify() popup-menu-pullright()",
"Canvas*paintBox*paint*popup-menu*translations: #override \
	<Key>Escape: unhighlight() MenuPopdown()\\n\
	<LeaveWindow>: unhighlight() MenuPopdown()\\n\
        <BtnMotion>: highlight() popup-menu-pullright()\\n\
        <BtnDown>: highlight() popup-menu-pullright()\\n\
        <BtnUp>: highlight() notify() popup-menu-pullright()",
"Canvas*menu*SimpleMenu.translations: #override \
        <BtnMotion>: highlight() popup-menu-pullright()",
"Canvas*fatbits.title:			XPaint / Fat Bits",
"Canvas*fatbits.iconName:		XPaint Fat Bits",
"Canvas*fatbits*done.label:		Done",
"Canvas*fatbits*paint.zoom:		6",
"Canvas*fatbits*zoomButton1.label:	1:2",
"Canvas*fatbits*zoomButton2.label:	1:4",
"Canvas*fatbits*zoomButton3.label:	1:6",
"Canvas*fatbits*zoomButton4.label:	1:8",
"Canvas*fatbits*zoomButton5.label:	1:16",
"xpaint*fontSelect.title:		XPaint / Browse and Select a Font",
"xpaint*fontSelect.iconName:		XPaint Font Browser",
"xpaint*fontSelect*vport.height:		280",
"xpaint*fontSelect*text.width:		620",
"xpaint*fontSelect*text.height:		70",
"xpaint*fontSelect*apply.label:		Apply",
"xpaint*fontSelect*done.label:		Close",
"xpaint*fontSelect*spacingLabel.label:	Spacing",
"xpaint*fontSelect*familyLabel.label:	Font Family",
"xpaint*fontSelect*weightLabel.label:	Weight/Style",
"xpaint*fontSelect*pointLabel.label:	Point Size:",
"xpaint*fontSelect*fontNameLabel.label:	Selection:",
"xpaint*fontSelect*fontName.width:	450",
"xpaint*fontSelect*List.translations:	<Btn1Down>: Set() Notify()",
"xpaint*pattern.title:			XPaint / Color and Pattern Selector",
"xpaint*pattern*paint.zoom:		6",
"xpaint*pattern*palette.label:		Palette",
"xpaint*pattern*palette*saveconfig.label:	Save Palette Config...",
"xpaint*pattern*palette*loadconfig.label:	Load New Palette...",
"xpaint*pattern*palette*markselected.label:	Mark Selected Pattern",
"xpaint*pattern*palette*unmark.label:		Unmark Pattern",
"xpaint*pattern*palette*loadmarked.label:	Load Marked Pattern",
"xpaint*pattern*palette*delete.label:	Remove Selected Pattern",
"xpaint*pattern*canvas.label:		Canevas",
"xpaint*pattern*canvas.label:		Canvas",
"xpaint*pattern*canvas*read.label:		Load",
"xpaint*pattern*canvas*save.label:		Save As...",
"xpaint*pattern*canvas*close.label:	Close",
"xpaint*pattern*edit.label:		Edit",
"xpaint*pattern*edit*undo.label:		Undo",
"xpaint*pattern*edit*cut.label:		Cut",
"xpaint*pattern*edit*copy.label:		Copy",
"xpaint*pattern*edit*paste.label:	Paste",
"xpaint*pattern*edit*clear.label:	Clear",
"xpaint*pattern*edit*dup.label:		Duplicate",
"xpaint*pattern*edit*all.label:		Select All",
"xpaint*pattern*popup-menu*select.label: Select...",
"xpaint*pattern*line.label:		Line",
"xpaint*pattern*line*select.label:	Line Width...",
"xpaint*pattern*line*dashstyle.label:	Dash Style...",
"xpaint*pattern*lookup.label:		Lookup",
"xpaint*pattern*grab.label:		Grab",
"xpaint*pattern*select.label:		Record",
"xpaint*pattern*asbrush.label:		New Brush",
"xpaint*pattern*size.label:		Size",
"xpaint*pattern*size*other.label:	Select...",
"xpaint*pattern*image.label:		Image",
"xpaint*pattern*image*grid.label:	Visible Grid",
"xpaint*pattern*image*zoom.label:	Zoom Factor",
"xpaint*pattern*image*background.label:	Background Color...",
"xpaint*pattern*help.label:		Help",
"xpaint*pattern*help*help.label:		Help...",
"xpaint*pattern*viewport*vertical.thickness: 14",
"xpaint*patternRackForm*popup-menu.label:	Pattern",
"xpaint*patternRackForm*popup-menu.mark.label:	Mark",
"xpaint*patternRackForm*popup-menu.unmark.label:	Unmark",
"xpaint*patternRackForm*popup-menu.loadpattern.label:	Load",
"xpaint*patternRackForm*popup-menu.edit.label:	Edit",
"xpaint*patternRackForm*popup-menu.remove.label:	Remove",
"xpaint*patternRackForm*popup-menu.help.label:	Help",
"xpaint*patternRackForm.vport.height:		100",
"xpaint*patternRackForm*viewport2*vertical.thickness:		14",
"xpaint*patternRackForm*viewport2.width:		604",
"xpaint*patternRackForm*viewport2.height:	180",
"xpaint*toolbox*vport*vertDistance:		2",
"xpaint*toolbox*box*vertDistance:	0",
"xpaint*toolbox*canvas.label:		Canvas",
"xpaint*toolbox*canvas*new.label:			New Canvas",
"xpaint*toolbox*canvas*new-size.label:		New With Size...",
"xpaint*toolbox*canvas*open.label:			Open Image...",
"xpaint*toolbox*canvas*snapshot.label:		Take Snapshot...",
"xpaint*toolbox*canvas*about.label:		About...",
"xpaint*toolbox*canvas*quit.label:			Quit XPaint",
"xpaint*toolbox*other.label:		Brush",
"xpaint*toolbox*other*brushSelect.label:		Select Brush Style",
"xpaint*toolbox*other*sprayEdit.label:		Edit Spray Pattern",
"xpaint*toolbox*help.label:			Help",
"xpaint*toolbox*help*intro.label:		Introduction",
"xpaint*toolbox*help*tools.label:		Toolbox",
"xpaint*toolbox*help*canvas.label:		Canvas",
"xpaint*toolbox*help*about.label:		About",
"xpaint*toolbox*help*copyright.label:		Copyright",
"xpaint*toolbox*pencil.popup-menu.label:		Pencil",
"xpaint*toolbox*dotPencil.popup-menu.label:	Dot Pencil",
"xpaint*toolbox*dynpencil.popup-menu.label:	DynPencil",
"xpaint*toolbox*dynpencil.popup-menu.autofinish.label:	AutoFinish",
"xpaint*toolbox*dynpencil.popup-menu.select.label:	Parameters...",
"xpaint*toolbox*brush.popup-menu.label:		Brush",
"xpaint*toolbox*brush.popup-menu.opaque.label:	Opaque",
"xpaint*toolbox*brush.popup-menu.transparent.label:	Transparent",
"xpaint*toolbox*brush.popup-menu.select.label:	Select Brush...",
"xpaint*toolbox*brush.popup-menu.parms.label:	Set Parameters...",
"xpaint*toolbox*erase.popup-menu.label:		Erase",
"xpaint*toolbox*erase.popup-menu.original.label:	Original",
"xpaint*toolbox*erase.popup-menu.select.label:	Select Brush...",
"xpaint*toolbox*spray.popup-menu.label:		Spray",
"xpaint*toolbox*spray.popup-menu.gauss.label:	Gauss",
"xpaint*toolbox*spray.popup-menu.select.label:	Set Parameters...",
"xpaint*toolbox*smear.popup-menu.label:		Smear",
"xpaint*toolbox*smear.popup-menu.select.label:	Select Brush...",
"xpaint*toolbox*line.popup-menu.label:		Line",
"xpaint*toolbox*ray.popup-menu.label:		Ray",
"xpaint*toolbox*arc.popup-menu.label:		Arc",
"xpaint*toolbox*arc.popup-menu*connect.label:	Circle Arc",
"xpaint*toolbox*arc.popup-menu*quadrant.label:	Elliptic Quadrant",
"xpaint*toolbox*arc.popup-menu*centered.label:	Centered Ellipse Arc",
"xpaint*toolbox*arc.popup-menu*boxed.label:	Boxed Ellipse Arc",
"xpaint*toolbox*popup-menu*center.label:		Center",
"xpaint*toolbox*line.popup-menu*ray.label:	Rays",
"xpaint*toolbox*line.popup-menu*arrow.label:	Arrow",
"xpaint*toolbox*fill.popup-menu.label:		Fill",
"xpaint*toolbox*tfill.popup-menu.label:		Gradient Fill",
"xpaint*toolbox*tfill.popup-menu.parms.label:	Set Parameters...",
"xpaint*toolbox*ffill.popup-menu.label:		Fractal Fill",
"xpaint*toolbox*ffill.popup-menu.parms.label:	Set Density...",
"xpaint*toolbox*ffill.popup-menu.plasma.label:	Plasma",
"xpaint*toolbox*ffill.popup-menu.clouds.label:	Clouds",
"xpaint*toolbox*ffill.popup-menu.landscape.label:	Land/Sea",
"xpaint*toolbox*popup-menu.fill.label:		Fill",
"xpaint*toolbox*popup-menu.change.label:		Change",
"xpaint*toolbox*popup-menu.fill_range.label:	Fill Range",
"xpaint*toolbox*popup-menu.radial.label:		Radial",
"xpaint*toolbox*popup-menu.linear.label:		Linear",
"xpaint*toolbox*popup-menu.conical.label:	Conical",
"xpaint*toolbox*popup-menu.square.label:		Square",
"xpaint*toolbox*popup-menu.rectangle.label:	Rectangle",
"xpaint*toolbox*popup-menu.ellipse.label:	Ellipse",
"xpaint*toolbox*text.popup-menu.label:		Text",
"xpaint*toolbox*text.popup-menu.select.label:	Select Font...",
"xpaint*toolbox*selectBox.popup-menu.label:	Select Box/Ellipse",
"xpaint*toolbox*lasso.popup-menu.label:		Lasso",
"xpaint*toolbox*selectPoly.popup-menu.label:	Select Polygon",
"xpaint*toolbox*popup-menu.shape.label:		All Colors",
"xpaint*toolbox*popup-menu.not_color.label:	Omit Color Range",
"xpaint*toolbox*popup-menu.only_color.label:	Only Color Range",
"xpaint*toolbox*popup-menu.select.label:		Select Range...",
"xpaint*toolbox*box.popup-menu.label:		Box",
"xpaint*toolbox*fBox.popup-menu.label:		Filled Box",
"xpaint*toolbox*oval.popup-menu.label:		Oval",
"xpaint*toolbox*fOval.popup-menu.label:		Filled Oval",
"xpaint*toolbox*cLine.popup-menu.label:		Connected Line",
"xpaint*toolbox*Spline.popup-menu.label:		Spline Curve",
"xpaint*toolbox*Spline.popup-menu.open.label:	Open",
"xpaint*toolbox*Spline.popup-menu.closed.label:	Closed",
"xpaint*toolbox*Spline.popup-menu.closed_up.label:	Closed up",
"xpaint*toolbox*fSpline.popup-menu.label:		Filled Spline Curve",
"xpaint*toolbox*fSpline.popup-menu.open.label:	Open",
"xpaint*toolbox*fSpline.popup-menu.closed.label:	Closed",
"xpaint*toolbox*fSpline.popup-menu.closed_up.label:	Closed up",
"xpaint*toolbox*polygon.popup-menu.label:	Polygon",
"xpaint*toolbox*fPolygon.popup-menu.label:	Filled Polygon",
"xpaint*toolbox*freehand.popup-menu.label:	Shape",
"xpaint*toolbox*fFreehand.popup-menu.label:	Filled Shape",
"xpaint*script_files.label:		File",
"xpaint*script_files*load.label:		Load",
"xpaint*script_files*save.label:		Save",
"xpaint*script_files*saveas.label:	Save as...",
"xpaint*script_files*editor.label:	External editor...",
"xpaint*script_files*close.label:	Close",
"xpaint*script_predef.label:		Templates",
"xpaint*script_predef*filters.label:	Filters",
"xpaint*script_predef*images.label:	Images",
"xpaint*script_predef*3d_curves.label:	3D Curves",
"xpaint*script_predef*3d_surfaces.label:	3D Surfaces",
"xpaint*script_predef*layers.label:	Layers",
"xpaint*script_predef*procedures.label:	Procedures",
"xpaint*script_predef*help.label:	Help",
"xpaint*compile.label:			Compile",
"Canvas*menu*file.label:			File",
"Canvas*menu*file*save.label:		Save",
"Canvas*menu*file*saveas.label:		Save As...",
"Canvas*menu*file*saveregion.label:	Save Region...",
"Canvas*menu*file*load-mem.label:	Load Clipboard...",
"Canvas*menu*file*saveconfig.label:	Save Palette...",
"Canvas*menu*file*loadconfig.label:	Load Palette...",
"Canvas*menu*file*revert.label:		Revert...",
"Canvas*menu*file*print.label:		Print...",
"Canvas*menu*file*extern.label:		External viewer...",
"Canvas*menu*file*close.label:		Close",
"Canvas.print*title:	Print Utility",
"Canvas.print*form*menu*format.label:		Format",
"Canvas.print*form*paperlabel.label:		Format",
"Canvas.print*form*portraitlabel.label:	Portrait",
"Canvas.print*form*portraittoggle.label:	X",
"Canvas.print*form*landscapelabel.label:	Landscape",
"Canvas.print*form*landscapetoggle.label:	X",
"Canvas.print*form*wcenter.label:	0",
"Canvas.print*form*wplus.label:	>",
"Canvas.print*form*wminus.label:	<",
"Canvas.print*form*wpplus.label:	»",
"Canvas.print*form*wmminus.label:	«",
"Canvas.print*form*hcenter.label:	0",
"Canvas.print*form*hplus.label:	>",
"Canvas.print*form*hminus.label:	<",
"Canvas.print*form*hpplus.label:	»",
"Canvas.print*form*hmminus.label:	«",
"Canvas.print*form*equal.label:	X",
"Canvas.print*form*synchro.horizDistance:	60",
"Canvas.print*form*sizelabel.label:		Size of image",
"Canvas.print*form*positionlabel.label:	Image position",
"Canvas.print*form*samplinglabel.label:	Sub sampling",
"Canvas.print*form*printlabel.label:		Printer command",
"Canvas.print*form*filelabel.label:		Write to file",
"Canvas.print*form*psviewerlabel.label:	PostScript viewer",
"Canvas.print*form*papertype*string:		A4",
"Canvas.print*form*papertype*horizDistance:	82",
"Canvas.print*form*sizevalue*string:		100%",
"Canvas.print*form*sizevalue*horizDistance:		136",
"Canvas.print*form*positionvalue*horizDistance:	136",
"Canvas.print*form*samplingvalue*string:	1 x 1",
"Canvas.print*form*samplingvalue*horizDistance:	136",
"Canvas.print*form*printcmd*string:	lpr -Plp",
"Canvas.print*form*printcmd*horizDistance:	136",
"Canvas.print*form*printtoggle.label:	X",
"Canvas.print*form*filetoggle.label:	X",
"Canvas.print*form*filename*horizDistance:	136",
"Canvas.print*form*psviewer*horizDistance:	136",
"Canvas.print*form*print*horizDistance:	136",
"Canvas.print*form*print.label:	Print",
"Canvas.print*form*preview.label:	Preview",
"Canvas.print*form*cancel.label:	Close",
"Canvas.print*form*psviewer*string:	gv",
"Canvas.extern*form*viewercmd*string:	xv",
"Canvas.extern*title:	External Image Viewer",
"Canvas.extern*form*format.label:		Exchange Format",
"Canvas.extern*form*formatlabel*label:		PPM",
"Canvas.extern*form*viewerlabel*label:	Viewer command",
"Canvas.extern*form*view*label:	View",
"Canvas.extern*form*cancel*label:	Close",
"Canvas*menu*edit.label:		Edit",
"Canvas*menu*edit*undo.label:		Undo",
"Canvas*menu*edit*redo.label:		Redo",
"Canvas*menu*edit*undosize.label:	Undo Levels...",
"Canvas*menu*edit*refresh.label:		Refresh",
"Canvas*menu*edit*cut.label:		Cut",
"Canvas*menu*edit*copy.label:		Copy",
"Canvas*menu*edit*paste.label:		Paste",
"Canvas*menu*edit*clear.label:		Clear",
"Canvas*menu*edit*dup.label:		Duplicate",
"Canvas*menu*edit*all.label:		Select All",
"Canvas*menu*edit*erase.label:		Erase All",
"Canvas*menu*edit*snapshot.label:	Snapshot",
"Canvas*menu*edit*memory.label:		Store Region",
"Canvas*menu*edit*recall.label:		Recall Image...",
"Canvas*menu*edit*remove.label:		Remove Image...",
"Canvas*menu*line.label:		Line",
"Canvas*menu*line*select.label:		Select...",
"Canvas*menu*line*dashstyle.label:	Dash Style...",
"Canvas*menu*font.label:		Font",
"Canvas*menu*font*select.label:		Browser...",
"Canvas*menu*region.label:	Region",
"Canvas*menu*region*flipX.label:		Flip X Axis",
"Canvas*menu*region*flipY.label:		Flip Y Axis",
"Canvas*menu*region*rotateTo.label:	Rotate By",
"Canvas*menu*rotateTo-right.label:	Angle",
"Canvas*menu*rotateTo-right*rotate1.label:	+90",
"Canvas*menu*rotateTo-right*rotate2.label:	+45",
"Canvas*menu*rotateTo-right*rotate3.label:	-45",
"Canvas*menu*rotateTo-right*rotate4.label:	-90",
"Canvas*menu*rotateTo-right*rotate5.label:	+180",
"Canvas*menu*region*rotate.label:	Rotate...",
"Canvas*menu*region*linear.label:	Linear Transformation...",
"Canvas*menu*region*clone.label:		Clone Region",
"Canvas*menu*region*crop.label:		Crop to Region...",
"Canvas*menu*region*autocrop.label:	Autocrop...",
"Canvas*menu*region*delimit.label:	Delimit Region",
"Canvas*menu*region*complement.label:	Complement Region",
"Canvas*menu*region*reset.label:		Reset",
"Canvas*menu*region*unselect.label:	Unselect",
"Canvas*menu*filter.label:	Filters",
"Canvas*menu*filter*invert.label:	Invert",
"Canvas*menu*filter*sharpen.label:	Sharpen",
"Canvas*menu*filter*smooth.label:	Smooth...",
"Canvas*menu*filter*dirfilt.label:	Directional Smooth",
"Canvas*menu*filter*edge.label:		Edge Detect",
"Canvas*menu*filter*oil.label:		Oil Paint...",
"Canvas*menu*filter*noise.label:		Add Noise...",
"Canvas*menu*filter*spread.label:	Spread...",
"Canvas*menu*filter*pixelize.label:	Pixelize...",
"Canvas*menu*filter*emboss.label:	Emboss",
"Canvas*menu*filter*despeckle.label:	Despeckle...",
"Canvas*menu*filter*tilt.label:		Tilt...",
"Canvas*menu*filter*blend.label:		Blend",
"Canvas*menu*filter*solarize.label:	Solarize...",
"Canvas*menu*filter*togrey.label:	Turn into Greyscale",
"Canvas*menu*filter*contrast.label:	Normalize Contrast...",
"Canvas*menu*filter*modify_rgb.label:	Adjust RGB components...",
"Canvas*menu*filter*quantize.label:	Quantize Colors...",
"Canvas*menu*filter*userdef.label:	User Defined Filter",
"Canvas*menu*filter*last.label:		Repeat Last",
"Canvas*menu*filter*undo.label:		Undo Last",
"Canvas*menu*selector.label:	Selectors",
"Canvas*menu*selector*patterns.label:    Color and Pattern Editor...",
"Canvas*menu*selector*background.label:  Change Background Color...",
"Canvas*menu*selector*chroma.label:	Select Color Range...",
"Canvas*menu*selector*fatbits.label:	Fat Bits Editor...",
"Canvas*menu*selector*tools.label:	Toolbox...",
"Canvas*menu*selector*brush.label:	Brush Selector...",
"Canvas*menu*selector*font.label:	Font Selector...",
"Canvas*menu*selector*c_script.label:	C script Editor...",
"Canvas*menu*selector*size.label:	Change Size...",
"Canvas*menu*selector*zoom.label:	Change Zoom...",
"Canvas*menu*selector*size_zoom_defs.label:	Default Size and Zoom...",
"Canvas*menu*selector*snapSpacing.label:	Snap Spacing...",
"Canvas*menu*selector*snap.label:	Snap",
"Canvas*menu*selector*grid.label:	Visible Grid",
"Canvas*menu*selector*simple.label:	Simplified Floating Menu",
"Canvas*menu*selector*hide_menubar.label:	Hide Menu Bar",
"Canvas*menu*selector*help.label:	Help",
"Canvas*menu*help.label:			Help",
"Canvas*menu*help*intro.label:		Introduction",
"Canvas*menu*help*tools.label:		Toolbox",
"Canvas*menu*help*canvas.label:		Canvas",
"Canvas*menu*help*about.label:		About",
"Canvas*menu*help*copyright.label:	Copyright",
"*paintBox*popup-menu.label:		General Menu",
"*paintBox*popup-menu.File.label:		File",
"*paintBox*popup-menu.File-right.label:		File",
"*paintBox*popup-menu.File-right*save.label:		Save",
"*paintBox*popup-menu.File-right*saveas.label:		Save As...",
"*paintBox*popup-menu.File-right*saveregion.label:	Save Region...",
"*paintBox*popup-menu.File-right*load-mem.label:		Load Clipboard...",
"*paintBox*popup-menu.File-right*saveconfig.label:	Save Palette...",
"*paintBox*popup-menu.File-right*loadconfig.label:	Load Palette...",
"*paintBox*popup-menu.File-right*revert.label:		Revert...",
"*paintBox*popup-menu.File-right*print.label:		Print...",
"*paintBox*popup-menu.File-right*extern.label:		External viewer...",
"*paintBox*popup-menu.File-right*close.label:		Close",
"*paintBox*popup-menu*Edit.label:		Edit",
"*paintBox*popup-menu.Edit-right.label:		Edit",
"*paintBox*popup-menu.Edit-right*undo.label:		Undo",
"*paintBox*popup-menu.Edit-right*redo.label:		Redo",
"*paintBox*popup-menu.Edit-right.undosize.label:		Undo Levels...",
"*paintBox*popup-menu.Edit-right*refresh.label:		Refresh",
"*paintBox*popup-menu.Edit-right*cut.label:		Cut",
"*paintBox*popup-menu.Edit-right*copy.label:		Copy",
"*paintBox*popup-menu.Edit-right*paste.label:		Paste",
"*paintBox*popup-menu.Edit-right*clear.label:		Clear",
"*paintBox*popup-menu.Edit-right*dup.label:		Duplicate",
"*paintBox*popup-menu.Edit-right*all.label:		Select All",
"*paintBox*popup-menu.Edit-right*erase.label:		Erase All",
"*paintBox*popup-menu.Edit-right*snapshot.label:		Snapshot",
"*paintBox*popup-menu.Edit-right.memory.label:		Store Region",
"*paintBox*popup-menu.Edit-right.recall.label:		Recall Image...",
"*paintBox*popup-menu.Edit-right.remove.label:		Remove Image...",
"*paintBox*popup-menu.Line.label:	Line",
"*paintBox*popup-menu.Line-right.label:	Line",
"*paintBox*popup-menu.Line-right.select.label:	Line Width...",
"*paintBox*popup-menu.Line-right.dashstyle.label:	Dash Style...",
"*paintBox*popup-menu.Font.label:	Font",
"*paintBox*popup-menu.Font-right.label:	Font",
"*paintBox*popup-menu.Font-right.select.label:	Browse...",
"*paintBox*popup-menu.Region.label:		Region",
"*paintBox*popup-menu.Region-right.label:		Region",
"*paintBox*popup-menu.Region-right.flipX.label:		Flip X Axis",
"*paintBox*popup-menu.Region-right.flipY.label:		Flip Y Axis",
"*paintBox*popup-menu.Region-right.rotateTo.label:	Rotate By",
"*paintBox*popup-menu.Region-right.rotate.label:	Rotate...",
"*paintBox*popup-menu.Region-right.rotateTo-right.label:	Angle",
"*paintBox*popup-menu.Region-right.rotateTo-right*rotate1.label:	+90",
"*paintBox*popup-menu.Region-right.rotateTo-right*rotate2.label:	+45",
"*paintBox*popup-menu.Region-right.rotateTo-right*rotate3.label:	-45",
"*paintBox*popup-menu.Region-right.rotateTo-right*rotate4.label:	-90",
"*paintBox*popup-menu.Region-right.rotateTo-right*rotate5.label:	+180",
"*paintBox*popup-menu.Region-right.linear.label:	Linear Transformation...",
"*paintBox*popup-menu.Region-right.reset.label:	Reset",
"*paintBox*popup-menu.Region-right*clone.label:	Clone Region",
"*paintBox*popup-menu.Region-right.crop.label:	Crop to Region...",
"*paintBox*popup-menu.Region-right.autocrop.label:	Autocrop",
"*paintBox*popup-menu.Region-right.delimit.label:	Delimit Region",
"*paintBox*popup-menu.Region-right.complement.label:	Complement Region",
"*paintBox*popup-menu.Region-right.unselect.label:	Unselect",
"*paintBox*popup-menu.Filters.label:		Filters",
"*paintBox*popup-menu.Filters-right.label:	Filters",
"*paintBox*popup-menu.Filters-right.invert.label:	Invert",
"*paintBox*popup-menu.Filters-right.sharpen.label:	Sharpen",
"*paintBox*popup-menu.Filters-right.smooth.label:	Smooth...",
"*paintBox*popup-menu.Filters-right.dirfilt.label:	Directional Smooth",
"*paintBox*popup-menu.Filters-right.edge.label:		Edge Detect",
"*paintBox*popup-menu.Filters-right.oil.label:		Oil Paint...",
"*paintBox*popup-menu.Filters-right.noise.label:		Add Noise...",
"*paintBox*popup-menu.Filters-right.spread.label:	Spread...",
"*paintBox*popup-menu.Filters-right.pixelize.label:	Pixelize...",
"*paintBox*popup-menu.Filters-right.emboss.label:	Emboss",
"*paintBox*popup-menu.Filters-right.despeckle.label:	Despeckle...",
"*paintBox*popup-menu.Filters-right.tilt.label:		Tilt...",
"*paintBox*popup-menu.Filters-right.blend.label:		Blend",
"*paintBox*popup-menu.Filters-right.solarize.label:	Solarize...",
"*paintBox*popup-menu.Filters-right.togrey.label:	Turn into Greyscale",
"*paintBox*popup-menu.Filters-right.contrast.label:	Normalize Contrast...",
"*paintBox*popup-menu.Filters-right.modify_rgb.label:	Adjust RGB components...",
"*paintBox*popup-menu.Filters-right.quantize.label:	Quantize Colors...",
"*paintBox*popup-menu.Filters-right.userdef.label:	Filtre Programmable...",
"*paintBox*popup-menu.Filters-right.last.label:		Repeat Last",
"*paintBox*popup-menu.Filters-right.undo.label:		Undo Last",
"*paintBox*popup-menu.Selectors.label:	Selectors",
"*paintBox*popup-menu.Selectors-right.label:	Selectors",
"*paintBox*popup-menu.Selectors-right*patterns.label:    Color and Pattern Editor...",
"*paintBox*popup-menu.Selectors-right*background.label:  Change Background Color...",
"*paintBox*popup-menu.Selectors-right*chroma.label:	Select Color Range...",
"*paintBox*popup-menu.Selectors-right*fatbits.label:	Fat Bits Editor...",
"*paintBox*popup-menu.Selectors-right*tools.label:	Toolbox...",
"*paintBox*popup-menu.Selectors-right*brush.label:	Brush Selector...",
"*paintBox*popup-menu.Selectors-right*font.label:	Font Selector...",
"*paintBox*popup-menu.Selectors-right*c_script.label:	C script Editor...",
"*paintBox*popup-menu.Selectors-right*size.label:	Change Size...",
"*paintBox*popup-menu.Selectors-right*zoom.label:	Change Zoom...",
"*paintBox*popup-menu.Selectors-right*size_zoom_defs.label:	Default Size and Zoom...",
"*paintBox*popup-menu.Selectors-right*snapSpacing.label:	Snap Spacing...",
"*paintBox*popup-menu.Selectors-right*snap.label:	Snap",
"*paintBox*popup-menu.Selectors-right*grid.label:	Visible Grid",
"*paintBox*popup-menu.Selectors-right.hide_menubar.label:	Hide Menu Bar",
"*paintBox*popup-menu.Selectors-right.show_menubar.label:	Show Menu Bar",
"*paintBox*popup-menu.Selectors-right*help.label:	Help",
"*filebrowser.title:		XPaint / File Browser",
"*filebrowser*text.width:		400",
"xpaint*brush*box.width: 170",
"xpaint*brush.title:			XPaint / Brush Selector",
"xpaint*brush.iconName:			XPaint Brush Selector",
"*colorPicker*match.label:		Lookup",
"*colorPicker*form.Label.width:	50",
"*colorPicker*Scrollbar.height:	16",
"*chroma.title:			XPaint / Color Range Selection",
"*chroma.iconName:			XPaint Chroma ",
"*chroma*varianceLabel.width:	120",
"*chroma*varianceBar.length:	140",
"*chroma*delta.label:		Pixel Delta",
"*chroma*selectModeLabel.label:	Selection Mode",
"*chroma*mode0.label:		All Hues",
"*chroma*mode1.label:		Omit Hue Range",
"*chroma*mode2.label:		Hue Range",
"*chroma*Label.justify:		left",
"xpaint*popup-dialog-form*label.justify:		left",
"Canvas*popup-dialog-form*label.justify: 	left",
"*colorEditDialog.title:		XPaint / Color Selector",
"xpaint*helpDialog.title:		XPaint / Help Browser",
"xpaint*helpDialog.iconName:		XPaint Help",
"xpaint*helpDialog.form.title.label:	XPaint 2.7.0 Help & Information",
"xpaint*helpDialog*textTitle.width:	400",
"xpaint*helpDialog*textText.width:	400",
"xpaint*helpDialog*textText.height:	256",
"xpaint*helpDialog*topicPort.height:	280",
"xpaint*helpDialog*done.label:		Done",
"xpaint*helpDialog*next.label:		Next",
"xpaint*helpDialog*prev.label:		Previous",
"xpaint*helpDialog*down.label:		Pg Down",
"xpaint*helpDialog*up.label:		Pg Up",
"xpaint*Font:				*-helvetica-medium-r-normal--12-*",
"Canvas*Font:				*-helvetica-medium-r-normal--12-*",
"xpaint*SimpleMenu.font:			*-helvetica-medium-r-normal--12-*",
"Canvas*SimpleMenu.font:			*-helvetica-medium-r-normal--12-*",
"xpaint*SimpleMenu.menuLabel.font:	*-helvetica-medium-r-normal--12-*",
"Canvas*SimpleMenu.menuLabel.font:	*-helvetica-medium-r-normal--12-*",
"xpaint*SimpleMenu*SmeBSB.font:		*-helvetica-medium-r-normal--12-*",
"Canvas*SimpleMenu*SmeBSB.font:		*-helvetica-medium-r-normal--12-*",
"Canvas*patternRackForm*Label.font:	*-helvetica-medium-r-normal--12-*",
"Canvas*patternRackForm*Command.font:	*-helvetica-medium-r-normal--12-*",
"xpaint*helpDialog*htmlText*font:	*-helvetica-medium-r-normal--12-*",
"xpaint*helpDialog*textText*font:	*-helvetica-medium-r-normal--12-*",
"xpaint*helpDialog.form.title.font:	*-helvetica-medium-r-normal--12-*",
"xpaint*helpDialog.form.form.font:	*-helvetica-medium-r-normal--12-*",
"xpaint*fontSelect*fontNameLabel.font:	*-helvetica-medium-r-normal--12-*",
"xpaint*fontSelect*fontName*font:	*-helvetica-medium-r-normal--12-*",
"Canvas*background:	white",
"Canvas*foreground:	black",
"Canvas*background:		#c0c0c0",
"Canvas*paint*background:	white",
"Canvas*paint*popup-menu*background: #c0c0c0",
"xpaint*background:		#c0c0c0",
"xpaint*foreground:		black",
"xpaint*Box.background:		gray80",
"Canvas*Box.background:		gray80",
"xpaint*Toggle.background:	#c0c0c0",
"Canvas*Toggle.background:	#c0c0c0",
"xpaint*Text*background:		#ffffff",
"xpaint*HTML*background:		#ffffff",
"Canvas*Text*background:		#ffffff",
"xpaint*filebrowser*Label.background:	gray80",
"xpaint*filebrowser*Toggle.background:	#c0c0c0",
"xpaint*filebrowser*name*background:	white",
"xpaint*filebrowser*title.background:	#c0c0c0",
"Canvas*filebrowser*Label.background:	gray80",
"Canvas*filebrowser*Toggle.background:	#c0c0c0",
"Canvas*filebrowser*name*background:	white",
"Canvas*filebrowser*title.background:	#c0c0c0",
"xpaint*Command.background:		#c0c0c0",
"Canvas*Command.background:		#c0c0c0",
"Canvas.pane.background:		black",
