#define CANT_FIND_APP_DEFAULTS_FILE 0
#define USAGE_FOR 1
#define CANNOT_INSTALL_XPM_ICON 2
#define NO_MATCH_FOUND_FOR_VISUAL 3
#define BAD_VISUAL_TYPE_SPECIFICATION 4
#define YOUR_CANVAS_DEPTH_IS_THAT_MANY_BITS 5
#define SEPARATOR_STRIP_ONE 6
#define WARNING_ONE 7
#define SEPARATOR_STRIP_TWO 8
#define WARNING_TWO_A 9
#define WARNING_TWO_B 10
#define WARNING_THREE_A 11
#define WARNING_THREE_B 12
#define WARNING_THREE_C 13
#define NO_FILE_NAME_SUPPLIED 14
#define UNABLE_TO_GET_REGION 15
#define UNABLE_TO_CREATE_IMAGE 16
#define UNABLE_TO_CREATE_IMAGE_FOR_SAVING 17
#define ERROR_SAVING_FILE 18
#define NO_REGION_SELECTED_PRESENTLY 19
#define NO_SUCH_FILE_OR_DIRECTORY 20
#define UNABLE_TO_OPEN_INPUT_FILE 21
#define IMAGE_FORMATS 22
#define END_IMAGE_FORMATS 37
#define POSITION 37
#define VALUE 38
#define RED_COLOR 39
#define GREEN_COLOR 40
#define BLUE_COLOR 41
#define RED_VARIANCE 42
#define GREEN_VARIANCE 43
#define BLUE_VARIANCE 44
#define SPACING 45
#define ENTER_DESIRED_SNAP_SPACING 46
#define LEVELS 47
#define NUMBER_OF_UNDO_LEVELS 48
#define IMAGE_NUMBER 49
#define RECALL_AN_IMAGE 50
#define REMOVE_AN_IMAGE 51
#define ZOOM 52
#define CHANGE_ZOOM_FACTOR_FOR_IMAGE 53
#define ANGLE_IN_DEGREES 54
#define ENTER_DESIRED_ROTATION 55
#define ENTER_TWOBYTWO_MATRIX_ENTRIES 56
#define ENTER_POINTS 57
#define MUST_BE_ODD 58
#define ENTER_MASK_SIZE_FOR_OIL_PAINT_EFFECT 59
#define ENTER_MASK_SIZE_FOR_SMOOTHING_EFFECT 60
#define ENTER_DESIRED_NOISE_VARIANCE 61
#define DISTANCE_PIXELS 62
#define ENTER_THE_DESIRED_SPREAD_DISTANCE 63
#define WIDTH_X_HEIGHT_OR_SINGLE_NUMBER 64
#define ENTER_DESIRED_MEGAPIXEL_SIZE 65
#define ENTER_MASK_SIZE_FOR_DESPECKLE_FILTER 66
#define BLACK_LEVEL 67
#define WHITE_LEVEL 68
#define ENTER_LEVELS_FOR_CONTRAST_ADJUSTMENT 69
#define ENTER_THRESHOLD_FOR_SOLARIZE_FILTER 70
#define ENTER_DESIRED_SHIFT_FOR_RGB_COMPONENTS 71
#define RED_SHIFT 72
#define GREEN_SHIFT 73
#define BLUE_SHIFT 74
#define ENTER_DESIRED_NUMBER_OF_COLORS 75
#define SIZE_WIDTH 76
#define SIZE_HEIGHT 77
#define SIZE_ZOOM 78
#define ENTER_DESIRED_IMAGE_SIZE 79
#define LINE_WIDTH 80
#define ENTER_DESIRED_LINE_WIDTH 81
#define ENTER_DESIRED_DASH_STYLE 82
#define DASH_STYLE 83
#define OPACITY 84
#define ENTER_THE_DESIRED_BRUSH_PARAMETERS 85
#define DENSITY 86
#define ENTER_THE_DESIRED_FRACTAL_DENSITY 87
#define DYNAMIC_WIDTH 88
#define DYNAMIC_MASS 89
#define DYNAMIC_DRAG 90
#define ENTER_THE_DESIRED_DYNAMIC_PENCIL_PARAMETERS 91
#define SPRAY_RADIUS 92
#define SPRAY_DENSITY 93
#define SPRAY_RATE 94
#define ENTER_THE_DESIRED_SPRAY_PARAMETERS 95
#define GRADIENT_ANGLE 96
#define GRADIENT_PAD 97
#define GRADIENT_HORIZONTAL_OFFSET 98
#define GRADIENT_VERTICAL_OFFSET 99
#define GRADIENT_STEPS 100
#define ENTER_THE_DESIRED_GRADIENT_FILL_PARAMETERS 101
#define PATTERN_WIDTH 102
#define PATTERN_HEIGHT 103
#define ENTER_THE_DESIRED_PATTERN_SIZE 104
#define YOU_MUST_HAVE_AT_LEAST_ONE_ENTRY 105
#define NO_INFORMATION_TO_SAVE 106
#define UNABLE_TO_OPEN_FILE 107
#define UNABLE_TO_OPEN_FILE_FOR_WRITING 108
#define UNSAVED_CHANGES_WISH_TO_QUIT 109
#define UNSAVED_CHANGES_WISH_TO_CLOSE 110
#define UNSAVED_CHANGES_WISH_TO_REVERT 111
#define RESIZING_WARNING_CANNOT_BE_UNDONE 112
#define AUTOCROP_WARNING_CANNOT_BE_UNDONE 113
#define ARE_YOU_SURE_YOU_WANT_TO_CROP_THE_IMAGE_TO_THE_SIZE_OF_THE_REGION 114
#define BAD_SNAP_SPACING 115
#define BAD_NUMBER_OF_UNDO_LEVELS 116
#define INVALID_ZOOM 117
#define INVALID_MASK_SIZE 118
#define INVALID_NOISE_VARIANCE 119
#define INVALID_SPREAD_DISTANCE 120
#define INVALID_PIXEL_SIZE 121
#define INVALID_WHITE_LEVEL 122
#define INVALID_BLACK_LEVEL 123
#define INVALID_SOLARIZATION_THRESHOLD 124
#define INVALID_RGB_PERCENTAGES 125
#define INVALID_NUMBER_OF_COLORS 126
#define UNABLE_TO_CREATE_PAINT_WINDOW_WITH_IMAGE 127
#define FILE_WRITTEN 128
#define FILE_SENT_TO_PRINTER 129
#define INVALID_WIDTH_MUST_BE_GREATER_THAN_ZERO 130
#define DASH_IS_GIVEN_BY_ALTERNATING_SUCH_CHARACTERS 131
#define OPACITY_SHOULD_BE_BETWEEN_ZERO_AND_HUNDRED_PERCENT 132
#define WIDTH_SHOULD_BE_BETWEEN_ONE_AND_ONE_HUNDRED 133
#define MASS_SHOULD_BE_BETWEEN_TEN_AND_TWO_THOUSAND 134
#define DRAG_SHOULD_BE_BETWEEN_ZERO_AND_FIFTY 135
#define RADIUS_SHOULD_BE_BETWEEN_ONE_AND_ONE_HUNDRED 136
#define DENSITY_SHOULD_BE_BETWEEN_ONE_AND_FIVE_HUNDRED 137
#define RATE_SHOULD_BE_BETWEEN_ONE_AND_FIVE_HUNDRED 138
#define HORIZONTAL_OFFSET_SHOULD_BE_BETWEEN_PLUS_MINUS_HUNDRED_PERCENT 139
#define VERTICAL_OFFSET_SHOULD_BE_BETWEEN_PLUS_MINUS_HUNDRED_PERCENT 140
#define PAD_SHOULD_BE_BETWEEN_PLUS_MINUS_FOURTY_NINE_PERCENT 141
#define ANGLE_SHOULD_BE_BETWEEN_PLUS_MINUS_THREE_HUNDRED_SIXTY_DEGREES 142
#define NUMBER_OF_STEPS_SHOULD_BE_BETWEEN_ONE_AND_THREE_HUNDRED 143
#define SELECT_THE_FONT_PROPERTIES_YOU_WISH 144
#define UNABLE_TO_LOAD_REQUESTED_FONT 145
#define YOU_MUST_FIRST_COMPILE_A_C_SCRIPT 146
#define C_SCRIPT_SUCCESSFULLY_COMPILED_AND_LINKED 147
#define C_SCRIPT_COULD_NOT_BE_COMPILED_OR_LINKED 148
#define INVALID_WIDTH 149
#define INVALID_HEIGHT 150
#define DIRECTORIES 151
#define FILES 152
#define OPEN_FILE_NAMED 153
#define SAVE_IN_FILE 154
#define LOAD_FROM_FILE 155
#define IMAGE_NUMBER_OUT_OF_RANGE 156
#define OUT_OF_MEMORY 157
#define UNABLE_TO_ALLOCATE_SUFFICIENT_COLOR_ENTRIES 158
#define TRY_EXITING_OTHER_COLOR_INTENSIVE_APPLICATIONS 159
#define SHOULDNT_HAPPEN 160
#define ERROR_IN_XINTERNATOM 161
#define CANNOT_GRAB_POINTER 162
#define INSUFFICIENT_RESOURCES_FOR_OPERATION 163
#define PROBABLY_NOT_ENOUGH_MEMORY_TO_ALLOCATE_PIXMAP 164
#define ERROR_CODE 165
#define UNKNOWN_IMAGE_FORMAT 166
#define OUT_OF_MEMORY_ALLOCATING_A_ROW 167
#define OUT_OF_MEMORY_ALLOCATING_AN_ARRAY 168
#define READ_ERROR 169
#define WRITE_ERROR 170
#define A_FILE_READ_ERROR_OCCURRED_AT_SOME_POINT 171
#define A_FILE_WRITE_ERROR_OCCURRED_AT_SOME_POINT 172
#define JUNK_IN_FILE_WHERE_BITS_SHOULD_BE 173
#define READ_ERROR_READING_MAGIC_NUMBER 174
#define JUNK_IN_FILE_WHERE_AN_INTEGER_SHOULD_BE 175
#define CANT_HAPPEN 176
#define MAXVAL_IS_TOO_LARGE 177
#define BAD_MAGIC_NUMBER_NOT_A_PPM_PGM_OR_PBM_FILE 178
#define OUT_OF_MEMORY_COMPUTING_HASH_TABLE 179
#define OUT_OF_MEMORY_ALLOCATING_HASH_TABLE 180
#define OUT_OF_MEMORY_GENERATING_HISTOGRAM 181
#define SAME_COLOR_FOUND_TWICE 182
#define COLORHIST_OUT_OF_MEMORY 183
#define FATAL_LIBPNG_ERROR_LONGJMP_CALLED_WHILE_READING 184
#define FATAL_LIBPNG_ERROR_LONGJMP_CALLED_WHILE_WRITING 185
#define ERROR_PLTE_CHUNK_NOT_FOUND_IN_PALETTE_IMAGE 186
#define STRIPPING_48_BIT_RGB_IMAGE_TO_24_BITS 187
#define STRIPPING_16_BIT_GRAYSCALE_IMAGE_TO_8_BITS 188
#define STRIPPING_64_BIT_RGBA_IMAGE_TO_32_BITS 189
#define STRIPPING_32_BIT_GRAY_ALPHA_IMAGE_TO_16_BITS 190
#define UNKNOWN_PNG_IMAGE_TYPE 191
#define READPNG_CANT_ALLOCATE_MEMORY_FOR_ROW_POINTERS_1 192
#define READPNG_CANT_ALLOCATE_MEMORY_FOR_ROW_POINTERS_2 193
#define UNABLE_TO_ALLOCATE_TEMPORARY_STORAGE_FOR_ALPHA_IMAGE 194
#define READPNG_UNABLE_TO_MALLOC_PNG_DATA 195
#define WRITEPNG_CANT_USE_ALPHA_MASK_WITH_COLORMAPPED_IMAGE 196
#define WRITEPNG_SORRY_CANT_WRITE_ALPHA_IMAGES_YET 197
#define WRITEPNG_CANT_ALLOCATE_MEMORY_FOR_ROW_POINTERS 198
#define XPAINT_FATAL_LIBPNG_ERROR 199
#define XPAINT_EXTREMELY_FATAL_LIBPNG_ERROR 200
#define END_MESSAGES 201

extern String *msgText;
extern int msgNum;
