#include <ctype.h>
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>

#include <X11/X.h>
#include <X11/Xlib.h>
#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>

#include "/usr/X11R6/share/xpaint/include/Paint.h"
#include "/usr/X11R6/share/xpaint/include/xpaint.h"
#include "/usr/X11R6/share/xpaint/include/graphic.h"
#include "/usr/X11R6/share/xpaint/include/image.h"
#include "/usr/X11R6/share/xpaint/include/misc.h"
#include "/usr/X11R6/share/xpaint/include/region.h"

